@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use parent qw/autobox/;
 
-our $VERSION = "1.015";
+our $VERSION = "1.016";
 
 =head1 NAME
 
@@ -18,6 +18,9 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
 
 =head2 Array Examples
 
+    # $books and $authors below are arrayrefs with either objects (or
+    # hashrefs)
+
     $books->map_by("genre");
     $books->map_by(price_with_tax => [$tax_pct]);
 
@@ -69,10 +72,6 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
     #     "SCI-FI"  => "3 books",
     # },
 
-    # Transform each pair to the string "n: genre"
-    $genre_count->map_each_to_array(sub { "$_: $_[0]" });
-    # [ "1: Fantasy", "3: Sci-fi" ]
-
     # Make the count say "n books"
     $genre_count->map_each_value(sub { "$_ books" });
     # {
@@ -80,6 +79,10 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
     #     "Sci-fi"  => "3 books",
     # },
 
+    # Transform each pair to the string "n: genre"
+    $genre_count->map_each_to_array(sub { "$_: $_[0]" });
+    # [ "1: Fantasy", "3: Sci-fi" ]
+
 
 =head2 Combined examples
 
@@ -193,6 +196,10 @@ $hash->map_each
 
 =item
 
+$hash->map_each_value
+
+=item
+
 $hash->map_each_to_array
 
 =back
@@ -220,8 +227,9 @@ operations etc.
 
 =back
 
-autobox::Transform provides a few higher level methods for mapping,
-greping and sorting common cases which are easier to read and write.
+On top of this, L<autobox::Transform> provides a few higher level
+methods for mapping, greping and sorting common cases which are easier
+to read and write.
 
 Since they are at a slightly higher semantic level, once you know them
 they also provide a more specific meaning than just "map" or "grep".
@@ -816,7 +824,7 @@ sub map_each_value {
     return wantarray ? %$new_hash : $new_hash;
 }
 
-=head2 map_each_to_array($item_subref) : %new_array | %$new_array
+=head2 map_each_to_array($item_subref) : @new_array | @$new_array
 
 Map each key-value pair in the hash into a list using the
 $item_subref.
@@ -825,7 +833,7 @@ C<$item_subref->($key, $value)> is called for each pair (with $_ set
 to the value) in key order.
 
 The subref should return zero or more list items which will make up
-the %new_array. Typically one item is returned.
+the @new_array. Typically one item is returned.
 
 =head3 Example
 
